---
template: mainpanel
source_form: markdown
name: Limitations
updated: July 2015
title: Limitations
---
## Limitations

Most expressions currently rely on the C++ counterparts. As a result not all
combinations which are valid are directly supported yet. Notable ones:

* Combinations of strings with other strings (outlawing /*, etc)
* Combinations of strings with numbers 
